pub enum KeyringIo {
Read(Result<SecretString, KeyringEntry>),
Write(Result<(), (KeyringEntry, SecretString)>),
Delete(Result<(), KeyringEntry>),
}Expand description
The keyring I/O request enum, emitted by coroutines and processed by runtimes.
Represents all the possible I/O requests that a stream coroutine can emit. Runtimes should be able to handle all variants.
Variants
Read(Result<SecretString, KeyringEntry>)
I/O for reading a secret from a keyring entry.
Input: keyring entry
Output: secret string
Write(Result<(), (KeyringEntry, SecretString)>)
I/O for saving a keyring entry secret.
Input: keyring entry with secret string
Output: none
Delete(Result<(), KeyringEntry>)
I/O for deleting a keyring entry.
Input: keyring entry
Output: none